@@ -7,3 +7,6 @@ pub mod biguint_ser;
 pub use num_bigint::*;
 pub use num_integer::{self, Integer};
 pub use num_traits::Zero;
+
+/// The maximum number of bytes we accept to serialize/deserialize for a single BigInt.
+pub const MAX_BIGINT_SIZE: usize = 128;
